@@ -189,28 +189,25 @@ class Module:
         self.subscribe_mqtt(f"$iothub/methods/POST/{name}/#", handler)
 
     def subscribe(self, type: str, cb):
-        [channel, mtype] = type.split("/")
-        if not mtype:
-            channel = 'message'
-            mtype = channel
+        if not '/' in type:
+            type = 'message/' + type
 
         def handler(topic: str, payload):
             args = json.loads(payload)
             type = topic.split("/")[3]
             cb(args, type)
 
-        self.subscribe_mqtt(f"ombori/grid/{mtype}/{mtype}", handler)
+        self.subscribe_mqtt(f"ombori/grid/{type}", handler)
 
     def on_event(self, type: str, cb):
         self.subscribe(type, cb)
 
     def publish(self, type: str, payload):
-        [channel, mtype] = type.split("/")
-        if not mtype:
-            channel = 'message'
-            mtype = channel
+        if not '/' in type:
+            type = 'message/' + type
+
         data = json.dumps(payload)
-        self.publish_mqtt(f"ombori/grid/{channel}/{mtype}", data)
+        self.publish_mqtt(f"ombori/grid/{type}", data)
 
     def broadcast(self, type: str, payload):
         self.publish(type, payload)
